@@ -42,7 +42,7 @@ DEFAULT_SPECD_PATH = os.path.join(
     os.path.dirname(__file__), "../../gosdk/specs/"
 )
 
-VERSION = "0.9.10"
+VERSION = "0.9.11"
 COPYRIGHT = "Copyright: GenomOncology, LLC"
 
 
@@ -215,6 +215,14 @@ def aggregate_csv(state, aggregate_key):
     ]
 
 
+@gocli.command()
+@options.build_option
+@options.pass_state
+def aggregate_omim_tsv(state):
+    """ Aggregate OMIM TSV file. """
+    return [sources.AggregatedOmimFileSource()]
+
+
 @gocli.command()
 @click.argument("cosmic_tsv_path", type=str)
 @options.build_option
@@ -381,6 +389,39 @@ def annotate_calls(
     ]
 
 
+@gocli.command()
+@options.build_option
+@options.pass_state
+@click.option(
+    "--delete-if-exists",
+    "-d",
+    "delete_if_exists",
+    help="Delete if annotations exist.",
+    is_flag=True,
+)
+@click.argument("template_name", type=str)
+def get_variant_interpretations(state, delete_if_exists, template_name):
+    """ Gets the variant interpretations, annotations,
+    and protein effects for the passed in variants. """
+    create_function = kms.create_sync_processor
+    sdk_function = kms.variant_interpretations.get_variant_interpretations
+
+    return [
+        filter(is_not_skipped_call),
+        partition_all(
+            state.batch_size
+        ),  # annotate calls is GET, hardcoded batch size
+        create_function(
+            state,
+            sdk_function,
+            delete_if_exists=delete_if_exists,
+            build=state.build,
+            template_name=template_name,
+        ),
+        concat,
+    ]
+
+
 @gocli.command()
 @options.build_option
 @options.pass_state
