@@ -6,7 +6,7 @@ import re
 
 NAME_MAPPING = {
     "gene": "gene",
-    "gene_mim__mstring": "Mim Number",
+    "gene_mim__mstring": "MIM Number",
     "phenotype__mstring": "phenotype",
     "phenotype_mim__mstring": "phenotype_mim",
     "inheritance__mstring": "inheritance",
@@ -40,6 +40,8 @@ def parse_omim_inheritance(omim_pheno_d):
         "Somatic mosaicism",
         "?X - linked recessive",
         "Inherited chromosomal imbalance",
+        "Pseudoautosomal dominant",
+        "Pseudoautosomal recessive",
     ]
 
     # structure of the phenotype field is:
@@ -47,6 +49,9 @@ def parse_omim_inheritance(omim_pheno_d):
     # so split on (digit) and take the stuff that comes after
     phen = omim_pheno_d["phenotype"]
     omim_inheritance_strings = re.compile(r"\(\d\)").split(phen)[-1]
+    phen_before_inheritance = phen[
+        0 : len(phen) - len(omim_inheritance_strings)
+    ]
     omim_inheritance_strings = omim_inheritance_strings.strip()
     omim_inheritance_values = split_filter(
         omim_inheritance_strings, ", ", lambda x: x in omim_inheritance_l
@@ -59,7 +64,7 @@ def parse_omim_inheritance(omim_pheno_d):
         omim_inheritance_strings, ", ", lambda x: x in omim_inheritance_l
     )
 
-    phen = phen.replace(omim_inheritance_strings, ", ".join(omim_leftovers))
+    phen = phen_before_inheritance + ", ".join(omim_leftovers)
     omim_pheno_d["phenotype"] = phen
 
     return omim_pheno_d
@@ -108,6 +113,9 @@ def parse_omim_phenotypes(x):
             # do not add any of the phenotypes fields if they are all None
             return x
 
+        # filter out Nones
+        x["Phenotypes"] = [phen for phen in x["Phenotypes"] if phen != "None"]
+
         x["Phenotypes"] = "; ".join(x["Phenotypes"])
         return merge_with(
             list, map(phenotype_pipeline, x["Phenotypes"].split("; "))
